"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RedisConfig(google.protobuf.message.Message):
    """Fields and structure of `RedisConfig` reflects Redis configuration file
    parameters.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MaxmemoryPolicy:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MaxmemoryPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RedisConfig._MaxmemoryPolicy.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        MAXMEMORY_POLICY_UNSPECIFIED: RedisConfig._MaxmemoryPolicy.ValueType  # 0
        VOLATILE_LRU: RedisConfig._MaxmemoryPolicy.ValueType  # 1
        """Try to remove less recently used (LRU) keys with `expire set`."""
        ALLKEYS_LRU: RedisConfig._MaxmemoryPolicy.ValueType  # 2
        """Remove less recently used (LRU) keys."""
        VOLATILE_LFU: RedisConfig._MaxmemoryPolicy.ValueType  # 3
        """Try to remove least frequently used (LFU) keys with `expire set`."""
        ALLKEYS_LFU: RedisConfig._MaxmemoryPolicy.ValueType  # 4
        """Remove least frequently used (LFU) keys."""
        VOLATILE_RANDOM: RedisConfig._MaxmemoryPolicy.ValueType  # 5
        """Try to remove keys with `expire set` randomly."""
        ALLKEYS_RANDOM: RedisConfig._MaxmemoryPolicy.ValueType  # 6
        """Remove keys randomly."""
        VOLATILE_TTL: RedisConfig._MaxmemoryPolicy.ValueType  # 7
        """Try to remove less recently used (LRU) keys with `expire set`
        and shorter TTL first.
        """
        NOEVICTION: RedisConfig._MaxmemoryPolicy.ValueType  # 8
        """Return errors when memory limit was reached and commands could require
        more memory to be used.
        """

    class MaxmemoryPolicy(_MaxmemoryPolicy, metaclass=_MaxmemoryPolicyEnumTypeWrapper): ...
    MAXMEMORY_POLICY_UNSPECIFIED: RedisConfig.MaxmemoryPolicy.ValueType  # 0
    VOLATILE_LRU: RedisConfig.MaxmemoryPolicy.ValueType  # 1
    """Try to remove less recently used (LRU) keys with `expire set`."""
    ALLKEYS_LRU: RedisConfig.MaxmemoryPolicy.ValueType  # 2
    """Remove less recently used (LRU) keys."""
    VOLATILE_LFU: RedisConfig.MaxmemoryPolicy.ValueType  # 3
    """Try to remove least frequently used (LFU) keys with `expire set`."""
    ALLKEYS_LFU: RedisConfig.MaxmemoryPolicy.ValueType  # 4
    """Remove least frequently used (LFU) keys."""
    VOLATILE_RANDOM: RedisConfig.MaxmemoryPolicy.ValueType  # 5
    """Try to remove keys with `expire set` randomly."""
    ALLKEYS_RANDOM: RedisConfig.MaxmemoryPolicy.ValueType  # 6
    """Remove keys randomly."""
    VOLATILE_TTL: RedisConfig.MaxmemoryPolicy.ValueType  # 7
    """Try to remove less recently used (LRU) keys with `expire set`
    and shorter TTL first.
    """
    NOEVICTION: RedisConfig.MaxmemoryPolicy.ValueType  # 8
    """Return errors when memory limit was reached and commands could require
    more memory to be used.
    """

    @typing.final
    class ClientOutputBufferLimit(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HARD_LIMIT_FIELD_NUMBER: builtins.int
        SOFT_LIMIT_FIELD_NUMBER: builtins.int
        SOFT_SECONDS_FIELD_NUMBER: builtins.int
        @property
        def hard_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Total limit in bytes."""

        @property
        def soft_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Limit in bytes during certain time period."""

        @property
        def soft_seconds(self) -> google.protobuf.wrappers_pb2.Int64Value:
            """Seconds for soft limit."""

        def __init__(
            self,
            *,
            hard_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            soft_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            soft_seconds: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["hard_limit", b"hard_limit", "soft_limit", b"soft_limit", "soft_seconds", b"soft_seconds"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["hard_limit", b"hard_limit", "soft_limit", b"soft_limit", "soft_seconds", b"soft_seconds"]) -> None: ...

    MAXMEMORY_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    DATABASES_FIELD_NUMBER: builtins.int
    SLOWLOG_LOG_SLOWER_THAN_FIELD_NUMBER: builtins.int
    SLOWLOG_MAX_LEN_FIELD_NUMBER: builtins.int
    NOTIFY_KEYSPACE_EVENTS_FIELD_NUMBER: builtins.int
    CLIENT_OUTPUT_BUFFER_LIMIT_PUBSUB_FIELD_NUMBER: builtins.int
    CLIENT_OUTPUT_BUFFER_LIMIT_NORMAL_FIELD_NUMBER: builtins.int
    MAXMEMORY_PERCENT_FIELD_NUMBER: builtins.int
    LUA_TIME_LIMIT_FIELD_NUMBER: builtins.int
    REPL_BACKLOG_SIZE_PERCENT_FIELD_NUMBER: builtins.int
    CLUSTER_REQUIRE_FULL_COVERAGE_FIELD_NUMBER: builtins.int
    CLUSTER_ALLOW_READS_WHEN_DOWN_FIELD_NUMBER: builtins.int
    CLUSTER_ALLOW_PUBSUBSHARD_WHEN_DOWN_FIELD_NUMBER: builtins.int
    LFU_DECAY_TIME_FIELD_NUMBER: builtins.int
    LFU_LOG_FACTOR_FIELD_NUMBER: builtins.int
    TURN_BEFORE_SWITCHOVER_FIELD_NUMBER: builtins.int
    ALLOW_DATA_LOSS_FIELD_NUMBER: builtins.int
    maxmemory_policy: global___RedisConfig.MaxmemoryPolicy.ValueType
    """Redis key eviction policy for a dataset that reaches maximum memory,
    available to the host. Redis maxmemory setting depends on Managed
    Service for Redis [host class](/docs/managed-redis/concepts/instance-types).

    All policies are described in detail in [Redis documentation](https://redis.io/topics/lru-cache).
    """
    password: builtins.str
    """Authentication password."""
    notify_keyspace_events: builtins.str
    """String setting for pub\\sub functionality."""
    @property
    def timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Time that Redis keeps the connection open while the client is idle.
        If no new command is sent during that time, the connection is closed.
        """

    @property
    def databases(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Number of database buckets on a single redis-server process."""

    @property
    def slowlog_log_slower_than(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Threshold for logging slow requests to server in microseconds (log only slower than it)."""

    @property
    def slowlog_max_len(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Max slow requests number to log."""

    @property
    def client_output_buffer_limit_pubsub(self) -> global___RedisConfig.ClientOutputBufferLimit:
        """Redis connection output buffers limits for pubsub operations."""

    @property
    def client_output_buffer_limit_normal(self) -> global___RedisConfig.ClientOutputBufferLimit:
        """Redis connection output buffers limits for clients."""

    @property
    def maxmemory_percent(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Redis maxmemory percent"""

    @property
    def lua_time_limit(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum time in milliseconds for Lua scripts, 0 - disabled mechanism"""

    @property
    def repl_backlog_size_percent(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Replication backlog size as a percentage of flavor maxmemory"""

    @property
    def cluster_require_full_coverage(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls whether all hash slots must be covered by nodes"""

    @property
    def cluster_allow_reads_when_down(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Allows read operations when cluster is down"""

    @property
    def cluster_allow_pubsubshard_when_down(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Permits Pub/Sub shard operations when cluster is down"""

    @property
    def lfu_decay_time(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The time, in minutes, that must elapse in order for the key counter to be divided by two (or decremented if it has a value less <= 10)"""

    @property
    def lfu_log_factor(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Determines how the frequency counter represents key hits."""

    @property
    def turn_before_switchover(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Allows to turn before switchover in RDSync"""

    @property
    def allow_data_loss(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Allows some data to be lost in favor of faster switchover/restart"""

    def __init__(
        self,
        *,
        maxmemory_policy: global___RedisConfig.MaxmemoryPolicy.ValueType = ...,
        timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        password: builtins.str = ...,
        databases: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        slowlog_log_slower_than: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        slowlog_max_len: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        notify_keyspace_events: builtins.str = ...,
        client_output_buffer_limit_pubsub: global___RedisConfig.ClientOutputBufferLimit | None = ...,
        client_output_buffer_limit_normal: global___RedisConfig.ClientOutputBufferLimit | None = ...,
        maxmemory_percent: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lua_time_limit: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        repl_backlog_size_percent: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        cluster_require_full_coverage: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        cluster_allow_reads_when_down: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        cluster_allow_pubsubshard_when_down: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        lfu_decay_time: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        lfu_log_factor: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        turn_before_switchover: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        allow_data_loss: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allow_data_loss", b"allow_data_loss", "client_output_buffer_limit_normal", b"client_output_buffer_limit_normal", "client_output_buffer_limit_pubsub", b"client_output_buffer_limit_pubsub", "cluster_allow_pubsubshard_when_down", b"cluster_allow_pubsubshard_when_down", "cluster_allow_reads_when_down", b"cluster_allow_reads_when_down", "cluster_require_full_coverage", b"cluster_require_full_coverage", "databases", b"databases", "lfu_decay_time", b"lfu_decay_time", "lfu_log_factor", b"lfu_log_factor", "lua_time_limit", b"lua_time_limit", "maxmemory_percent", b"maxmemory_percent", "repl_backlog_size_percent", b"repl_backlog_size_percent", "slowlog_log_slower_than", b"slowlog_log_slower_than", "slowlog_max_len", b"slowlog_max_len", "timeout", b"timeout", "turn_before_switchover", b"turn_before_switchover"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_data_loss", b"allow_data_loss", "client_output_buffer_limit_normal", b"client_output_buffer_limit_normal", "client_output_buffer_limit_pubsub", b"client_output_buffer_limit_pubsub", "cluster_allow_pubsubshard_when_down", b"cluster_allow_pubsubshard_when_down", "cluster_allow_reads_when_down", b"cluster_allow_reads_when_down", "cluster_require_full_coverage", b"cluster_require_full_coverage", "databases", b"databases", "lfu_decay_time", b"lfu_decay_time", "lfu_log_factor", b"lfu_log_factor", "lua_time_limit", b"lua_time_limit", "maxmemory_percent", b"maxmemory_percent", "maxmemory_policy", b"maxmemory_policy", "notify_keyspace_events", b"notify_keyspace_events", "password", b"password", "repl_backlog_size_percent", b"repl_backlog_size_percent", "slowlog_log_slower_than", b"slowlog_log_slower_than", "slowlog_max_len", b"slowlog_max_len", "timeout", b"timeout", "turn_before_switchover", b"turn_before_switchover"]) -> None: ...

global___RedisConfig = RedisConfig

@typing.final
class RedisConfigSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___RedisConfig:
        """Effective settings for a Redis cluster (a combination of settings
        defined in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___RedisConfig:
        """User-defined settings for a Redis cluster."""

    @property
    def default_config(self) -> global___RedisConfig:
        """Default configuration for a Redis cluster."""

    def __init__(
        self,
        *,
        effective_config: global___RedisConfig | None = ...,
        user_config: global___RedisConfig | None = ...,
        default_config: global___RedisConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___RedisConfigSet = RedisConfigSet



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ElasticsearchConfig7(google.protobuf.message.Message):
    """Elasticsearch 7.x supported configuration options are listed here.

    Detailed description for each set of options is available in [Elasticsearch documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/index.html).

    Any options that are not listed here are not supported.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CLAUSE_COUNT_FIELD_NUMBER: builtins.int
    FIELDDATA_CACHE_SIZE_FIELD_NUMBER: builtins.int
    REINDEX_REMOTE_WHITELIST_FIELD_NUMBER: builtins.int
    REINDEX_SSL_CA_PATH_FIELD_NUMBER: builtins.int
    fielddata_cache_size: builtins.str
    """The maximum percentage or absolute value (10%, 512mb) of heap space that is allocated to field data cache.

    All the field values that are placed in this cache, get loaded to memory in order to provide fast document based access to those values.
    Building the field data cache for a field can be an expensive operations, so its recommended to have enough memory for this cache, and to keep it loaded.

    Default value: unbounded.

    See in-depth description in [Elasticsearch documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/modules-fielddata.html).
    """
    reindex_remote_whitelist: builtins.str
    """Remote hosts for reindex have to be explicitly allowed in elasticsearch.yml using the reindex.remote.whitelist property.
    It can be set to a comma delimited list of allowed remote host and port combinations.
    Scheme is ignored, only the host and port are used.
    """
    reindex_ssl_ca_path: builtins.str
    """List of paths to PEM encoded certificate files that should be trusted.

    See in-depth description in [Elasticsearch documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-reindex.html#reindex-ssl)
    """
    @property
    def max_clause_count(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of clauses a boolean query can contain.

        The limit is in place to prevent searches from becoming too large and taking up too much CPU and memory.
        It affects not only Elasticsearch's `bool` query, but many other queries that are implicitly converted to `bool` query by Elastcsearch.

        Default value: `1024`.

        See in-depth description in [Elasticsearch documentation](https://www.elastic.co/guide/en/elasticsearch/reference/current/search-settings.html).
        """

    def __init__(
        self,
        *,
        max_clause_count: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        fielddata_cache_size: builtins.str = ...,
        reindex_remote_whitelist: builtins.str = ...,
        reindex_ssl_ca_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_clause_count", b"max_clause_count"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["fielddata_cache_size", b"fielddata_cache_size", "max_clause_count", b"max_clause_count", "reindex_remote_whitelist", b"reindex_remote_whitelist", "reindex_ssl_ca_path", b"reindex_ssl_ca_path"]) -> None: ...

global___ElasticsearchConfig7 = ElasticsearchConfig7

@typing.final
class ElasticsearchConfigSet7(google.protobuf.message.Message):
    """Elasticsearch 7.x data node configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___ElasticsearchConfig7:
        """Effective settings for an Elasticsearch cluster (a combination of settings defined in [user_config] and [default_config])."""

    @property
    def user_config(self) -> global___ElasticsearchConfig7:
        """User-defined settings for an Elasticsearch cluster."""

    @property
    def default_config(self) -> global___ElasticsearchConfig7:
        """Default settings for an Elasticsearch cluster."""

    def __init__(
        self,
        *,
        effective_config: global___ElasticsearchConfig7 | None = ...,
        user_config: global___ElasticsearchConfig7 | None = ...,
        default_config: global___ElasticsearchConfig7 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___ElasticsearchConfigSet7 = ElasticsearchConfigSet7



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cdn.v1.origin_pb2
import yandex.cloud.cdn.v1.origin_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class OriginServiceStub:
    """
    Origin management service.
    Origin is not a standalone entity. It can live only within origin group.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.GetOriginRequest,
        yandex.cloud.cdn.v1.origin_pb2.Origin,
    ]
    """Get origin in origin group."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.ListOriginsRequest,
        yandex.cloud.cdn.v1.origin_service_pb2.ListOriginsResponse,
    ]
    """Lists origins of origin group."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.CreateOriginRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates origin inside origin group."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.UpdateOriginRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified origin from the origin group.

    Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge cache of the resources that
    use the origin via a [CacheService.Purge] request.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.DeleteOriginRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes origin from origin group."""

class OriginServiceAsyncStub:
    """
    Origin management service.
    Origin is not a standalone entity. It can live only within origin group.
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.GetOriginRequest,
        yandex.cloud.cdn.v1.origin_pb2.Origin,
    ]
    """Get origin in origin group."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.ListOriginsRequest,
        yandex.cloud.cdn.v1.origin_service_pb2.ListOriginsResponse,
    ]
    """Lists origins of origin group."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.CreateOriginRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates origin inside origin group."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.UpdateOriginRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified origin from the origin group.

    Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge cache of the resources that
    use the origin via a [CacheService.Purge] request.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.origin_service_pb2.DeleteOriginRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes origin from origin group."""

class OriginServiceServicer(metaclass=abc.ABCMeta):
    """
    Origin management service.
    Origin is not a standalone entity. It can live only within origin group.
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.cdn.v1.origin_service_pb2.GetOriginRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.origin_pb2.Origin, collections.abc.Awaitable[yandex.cloud.cdn.v1.origin_pb2.Origin]]:
        """Get origin in origin group."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.cdn.v1.origin_service_pb2.ListOriginsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.origin_service_pb2.ListOriginsResponse, collections.abc.Awaitable[yandex.cloud.cdn.v1.origin_service_pb2.ListOriginsResponse]]:
        """Lists origins of origin group."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.cdn.v1.origin_service_pb2.CreateOriginRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates origin inside origin group."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.cdn.v1.origin_service_pb2.UpdateOriginRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified origin from the origin group.

        Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge cache of the resources that
        use the origin via a [CacheService.Purge] request.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.cdn.v1.origin_service_pb2.DeleteOriginRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes origin from origin group."""

def add_OriginServiceServicer_to_server(servicer: OriginServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/agent/log_settings.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/loadtesting/api/v1/agent/log_settings.proto\x12%yandex.cloud.loadtesting.api.v1.agent\x1a\x1dyandex/cloud/validation.proto\"3\n\x0bLogSettings\x12$\n\x12\x63loud_log_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50B|\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.agent.log_settings_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.loadtesting.api.v1.agentZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/agent;agent'
  _LOGSETTINGS.fields_by_name['cloud_log_group_id']._options = None
  _LOGSETTINGS.fields_by_name['cloud_log_group_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LOGSETTINGS']._serialized_start=130
  _globals['_LOGSETTINGS']._serialized_end=181
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/mdb/kafka/v1/connector.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xa5\x03\n\rConnectorSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ttasks_max\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\nproperties\x18\x03 \x03(\x0b\x32\x38.yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry\x12\x61\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x39.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpecH\x00\x12X\n\x18\x63onnector_config_s3_sink\x18\x0b \x01(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.ConnectorConfigS3SinkSpecH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10\x63onnector_configJ\x04\x08\x04\x10\n\"\xa9\x03\n\x13UpdateConnectorSpec\x12.\n\ttasks_max\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12R\n\nproperties\x18\x02 \x03(\x0b\x32>.yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry\x12\x61\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x39.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpecH\x00\x12^\n\x18\x63onnector_config_s3_sink\x18\x0b \x01(\x0b\x32:.yandex.cloud.mdb.kafka.v1.UpdateConnectorConfigS3SinkSpecH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10\x63onnector_configJ\x04\x08\x03\x10\n\"\xfd\x01\n\x1e\x43onnectorConfigMirrorMakerSpec\x12H\n\x0esource_cluster\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec\x12H\n\x0etarget_cluster\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec\x12\x0e\n\x06topics\x18\x03 \x01(\t\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xd6\x01\n\x15\x43lusterConnectionSpec\x12\r\n\x05\x61lias\x18\x01 \x01(\t\x12\x42\n\x0cthis_cluster\x18\x02 \x01(\x0b\x32*.yandex.cloud.mdb.kafka.v1.ThisClusterSpecH\x00\x12T\n\x10\x65xternal_cluster\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpecH\x00\x42\x14\n\x12\x63luster_connection\"\x11\n\x0fThisClusterSpec\"\xc0\x01\n\x1d\x45xternalClusterConnectionSpec\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\x15\n\rsasl_username\x18\x02 \x01(\t\x12\x15\n\rsasl_password\x18\x03 \x01(\t\x12\x16\n\x0esasl_mechanism\x18\x04 \x01(\t\x12\x19\n\x11security_protocol\x18\x05 \x01(\t\x12#\n\x1bssl_truststore_certificates\x18\x06 \x01(\t\"\xc5\x01\n\x19\x43onnectorConfigS3SinkSpec\x12\x0e\n\x06topics\x18\x01 \x01(\t\x12\x1d\n\x15\x66ile_compression_type\x18\x02 \x01(\t\x12\x35\n\x10\x66ile_max_records\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rs3_connection\x18\x04 \x01(\x0b\x32+.yandex.cloud.mdb.kafka.v1.S3ConnectionSpec\"\xac\x01\n\x1fUpdateConnectorConfigS3SinkSpec\x12\x0e\n\x06topics\x18\x01 \x01(\t\x12\x35\n\x10\x66ile_max_records\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x42\n\rs3_connection\x18\x03 \x01(\x0b\x32+.yandex.cloud.mdb.kafka.v1.S3ConnectionSpec\"{\n\x10S3ConnectionSpec\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12G\n\x0b\x65xternal_s3\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ExternalS3StorageSpecH\x00\x42\t\n\x07storage\"k\n\x15\x45xternalS3StorageSpec\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x19\n\x11secret_access_key\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\"\x98\x05\n\tConnector\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ttasks_max\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12H\n\nproperties\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry\x12;\n\x06health\x18\x04 \x01(\x0e\x32+.yandex.cloud.mdb.kafka.v1.Connector.Health\x12;\n\x06status\x18\x05 \x01(\x0e\x32+.yandex.cloud.mdb.kafka.v1.Connector.Status\x12\x12\n\ncluster_id\x18\x06 \x01(\t\x12]\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x35.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerH\x00\x12T\n\x18\x63onnector_config_s3_sink\x18\x0b \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ConnectorConfigS3SinkH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"@\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\n\n\x06PAUSED\x10\x03\x42\x12\n\x10\x63onnector_configJ\x04\x08\x07\x10\n\"\xf1\x01\n\x1a\x43onnectorConfigMirrorMaker\x12\x44\n\x0esource_cluster\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ClusterConnection\x12\x44\n\x0etarget_cluster\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ClusterConnection\x12\x0e\n\x06topics\x18\x03 \x01(\t\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xca\x01\n\x11\x43lusterConnection\x12\r\n\x05\x61lias\x18\x01 \x01(\t\x12>\n\x0cthis_cluster\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.kafka.v1.ThisClusterH\x00\x12P\n\x10\x65xternal_cluster\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionH\x00\x42\x14\n\x12\x63luster_connection\"\r\n\x0bThisCluster\"\x86\x01\n\x19\x45xternalClusterConnection\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\x15\n\rsasl_username\x18\x02 \x01(\t\x12\x16\n\x0esasl_mechanism\x18\x04 \x01(\t\x12\x19\n\x11security_protocol\x18\x05 \x01(\tJ\x04\x08\x03\x10\x04\"\xbd\x01\n\x15\x43onnectorConfigS3Sink\x12\x0e\n\x06topics\x18\x01 \x01(\t\x12\x1d\n\x15\x66ile_compression_type\x18\x02 \x01(\t\x12\x35\n\x10\x66ile_max_records\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12>\n\rs3_connection\x18\x04 \x01(\x0b\x32\'.yandex.cloud.mdb.kafka.v1.S3Connection\"s\n\x0cS3Connection\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x43\n\x0b\x65xternal_s3\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ExternalS3StorageH\x00\x42\t\n\x07storage\"L\n\x11\x45xternalS3Storage\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\tBd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.connector_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _CONNECTORSPEC_PROPERTIESENTRY._options = None
  _CONNECTORSPEC_PROPERTIESENTRY._serialized_options = b'8\001'
  _UPDATECONNECTORSPEC_PROPERTIESENTRY._options = None
  _UPDATECONNECTORSPEC_PROPERTIESENTRY._serialized_options = b'8\001'
  _CONNECTOR_PROPERTIESENTRY._options = None
  _CONNECTOR_PROPERTIESENTRY._serialized_options = b'8\001'
  _globals['_CONNECTORSPEC']._serialized_start=105
  _globals['_CONNECTORSPEC']._serialized_end=526
  _globals['_CONNECTORSPEC_PROPERTIESENTRY']._serialized_start=451
  _globals['_CONNECTORSPEC_PROPERTIESENTRY']._serialized_end=500
  _globals['_UPDATECONNECTORSPEC']._serialized_start=529
  _globals['_UPDATECONNECTORSPEC']._serialized_end=954
  _globals['_UPDATECONNECTORSPEC_PROPERTIESENTRY']._serialized_start=451
  _globals['_UPDATECONNECTORSPEC_PROPERTIESENTRY']._serialized_end=500
  _globals['_CONNECTORCONFIGMIRRORMAKERSPEC']._serialized_start=957
  _globals['_CONNECTORCONFIGMIRRORMAKERSPEC']._serialized_end=1210
  _globals['_CLUSTERCONNECTIONSPEC']._serialized_start=1213
  _globals['_CLUSTERCONNECTIONSPEC']._serialized_end=1427
  _globals['_THISCLUSTERSPEC']._serialized_start=1429
  _globals['_THISCLUSTERSPEC']._serialized_end=1446
  _globals['_EXTERNALCLUSTERCONNECTIONSPEC']._serialized_start=1449
  _globals['_EXTERNALCLUSTERCONNECTIONSPEC']._serialized_end=1641
  _globals['_CONNECTORCONFIGS3SINKSPEC']._serialized_start=1644
  _globals['_CONNECTORCONFIGS3SINKSPEC']._serialized_end=1841
  _globals['_UPDATECONNECTORCONFIGS3SINKSPEC']._serialized_start=1844
  _globals['_UPDATECONNECTORCONFIGS3SINKSPEC']._serialized_end=2016
  _globals['_S3CONNECTIONSPEC']._serialized_start=2018
  _globals['_S3CONNECTIONSPEC']._serialized_end=2141
  _globals['_EXTERNALS3STORAGESPEC']._serialized_start=2143
  _globals['_EXTERNALS3STORAGESPEC']._serialized_end=2250
  _globals['_CONNECTOR']._serialized_start=2253
  _globals['_CONNECTOR']._serialized_end=2917
  _globals['_CONNECTOR_PROPERTIESENTRY']._serialized_start=451
  _globals['_CONNECTOR_PROPERTIESENTRY']._serialized_end=500
  _globals['_CONNECTOR_HEALTH']._serialized_start=2776
  _globals['_CONNECTOR_HEALTH']._serialized_end=2825
  _globals['_CONNECTOR_STATUS']._serialized_start=2827
  _globals['_CONNECTOR_STATUS']._serialized_end=2891
  _globals['_CONNECTORCONFIGMIRRORMAKER']._serialized_start=2920
  _globals['_CONNECTORCONFIGMIRRORMAKER']._serialized_end=3161
  _globals['_CLUSTERCONNECTION']._serialized_start=3164
  _globals['_CLUSTERCONNECTION']._serialized_end=3366
  _globals['_THISCLUSTER']._serialized_start=3368
  _globals['_THISCLUSTER']._serialized_end=3381
  _globals['_EXTERNALCLUSTERCONNECTION']._serialized_start=3384
  _globals['_EXTERNALCLUSTERCONNECTION']._serialized_end=3518
  _globals['_CONNECTORCONFIGS3SINK']._serialized_start=3521
  _globals['_CONNECTORCONFIGS3SINK']._serialized_end=3710
  _globals['_S3CONNECTION']._serialized_start=3712
  _globals['_S3CONNECTION']._serialized_end=3827
  _globals['_EXTERNALS3STORAGE']._serialized_start=3829
  _globals['_EXTERNALS3STORAGE']._serialized_end=3905
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/report/status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/loadtesting/api/v1/report/status.proto\x12&yandex.cloud.loadtesting.api.v1.report*L\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0e\n\nCOLLECTING\x10\x01\x12\x0f\n\x0b\x43\x41LCULATING\x10\x02\x12\t\n\x05READY\x10\x03\x42\x7f\n*yandex.cloud.api.loadtesting.api.v1.reportZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report;reportb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.report.status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.loadtesting.api.v1.reportZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report;report'
  _globals['_STATUS']._serialized_start=95
  _globals['_STATUS']._serialized_end=171
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.type.dayofweek_pb2
import google.type.timeofday_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANYTIME_FIELD_NUMBER: builtins.int
    DAILY_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    WEEKLY_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    @property
    def anytime(self) -> global___AnytimeMaintenanceWindow:
        """Updating the master at any time."""

    @property
    def daily_maintenance_window(self) -> global___DailyMaintenanceWindow:
        """Updating the master on any day during the specified time window."""

    @property
    def weekly_maintenance_window(self) -> global___WeeklyMaintenanceWindow:
        """Updating the master on selected days during the specified time window."""

    def __init__(
        self,
        *,
        anytime: global___AnytimeMaintenanceWindow | None = ...,
        daily_maintenance_window: global___DailyMaintenanceWindow | None = ...,
        weekly_maintenance_window: global___WeeklyMaintenanceWindow | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["anytime", b"anytime", "daily_maintenance_window", b"daily_maintenance_window", "policy", b"policy", "weekly_maintenance_window", b"weekly_maintenance_window"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["anytime", b"anytime", "daily_maintenance_window", b"daily_maintenance_window", "policy", b"policy", "weekly_maintenance_window", b"weekly_maintenance_window"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["policy", b"policy"]) -> typing.Literal["anytime", "daily_maintenance_window", "weekly_maintenance_window"] | None: ...

global___MaintenanceWindow = MaintenanceWindow

@typing.final
class AnytimeMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AnytimeMaintenanceWindow = AnytimeMaintenanceWindow

@typing.final
class DailyMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    @property
    def start_time(self) -> google.type.timeofday_pb2.TimeOfDay:
        """Window start time, in the UTC timezone."""

    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Window duration."""

    def __init__(
        self,
        *,
        start_time: google.type.timeofday_pb2.TimeOfDay | None = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["duration", b"duration", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["duration", b"duration", "start_time", b"start_time"]) -> None: ...

global___DailyMaintenanceWindow = DailyMaintenanceWindow

@typing.final
class DaysOfWeekMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    @property
    def days(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[google.type.dayofweek_pb2.DayOfWeek.ValueType]:
        """Days of the week when automatic updates are allowed."""

    @property
    def start_time(self) -> google.type.timeofday_pb2.TimeOfDay:
        """Window start time, in the UTC timezone."""

    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Window duration."""

    def __init__(
        self,
        *,
        days: collections.abc.Iterable[google.type.dayofweek_pb2.DayOfWeek.ValueType] | None = ...,
        start_time: google.type.timeofday_pb2.TimeOfDay | None = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["duration", b"duration", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["days", b"days", "duration", b"duration", "start_time", b"start_time"]) -> None: ...

global___DaysOfWeekMaintenanceWindow = DaysOfWeekMaintenanceWindow

@typing.final
class WeeklyMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAYS_OF_WEEK_FIELD_NUMBER: builtins.int
    @property
    def days_of_week(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaysOfWeekMaintenanceWindow]:
        """Days of the week and the maintenance window for these days when automatic updates are allowed."""

    def __init__(
        self,
        *,
        days_of_week: collections.abc.Iterable[global___DaysOfWeekMaintenanceWindow] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["days_of_week", b"days_of_week"]) -> None: ...

global___WeeklyMaintenanceWindow = WeeklyMaintenanceWindow



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/threads/thread_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from yandex.cloud.ai.assistants.v1.threads import message_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2
from yandex.cloud.ai.assistants.v1.threads import thread_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_thread__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/ai/assistants/v1/threads/thread_service.proto\x12%yandex.cloud.ai.assistants.v1.threads\x1a#yandex/cloud/ai/common/common.proto\x1a\x33yandex/cloud/ai/assistants/v1/threads/message.proto\x1a\x32yandex/cloud/ai/assistants/v1/threads/thread.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"\x86\x03\n\x13\x43reateThreadRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x44\n\x08messages\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.ai.assistants.v1.threads.MessageData\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12!\n\x19\x64\x65\x66\x61ult_message_author_id\x18\x05 \x01(\t\x12\x43\n\x11\x65xpiration_config\x18\x06 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12V\n\x06labels\x18\x07 \x03(\x0b\x32\x46.yandex.cloud.ai.assistants.v1.threads.CreateThreadRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x10GetThreadRequest\x12\x17\n\tthread_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xd4\x02\n\x13UpdateThreadRequest\x12\x17\n\tthread_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x43\n\x11\x65xpiration_config\x18\x05 \x01(\x0b\x32(.yandex.cloud.ai.common.ExpirationConfig\x12V\n\x06labels\x18\x06 \x03(\x0b\x32\x46.yandex.cloud.ai.assistants.v1.threads.UpdateThreadRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x13\x44\x65leteThreadRequest\x12\x17\n\tthread_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x16\n\x14\x44\x65leteThreadResponse\"T\n\x12ListThreadsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"n\n\x13ListThreadsResponse\x12>\n\x07threads\x18\x01 \x03(\x0b\x32-.yandex.cloud.ai.assistants.v1.threads.Thread\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xb9\x06\n\rThreadService\x12\x96\x01\n\x06\x43reate\x12:.yandex.cloud.ai.assistants.v1.threads.CreateThreadRequest\x1a-.yandex.cloud.ai.assistants.v1.threads.Thread\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/assistants/v1/threads:\x01*\x12\x99\x01\n\x03Get\x12\x37.yandex.cloud.ai.assistants.v1.threads.GetThreadRequest\x1a-.yandex.cloud.ai.assistants.v1.threads.Thread\"*\x82\xd3\xe4\x93\x02$\x12\"/assistants/v1/threads/{thread_id}\x12\xa2\x01\n\x06Update\x12:.yandex.cloud.ai.assistants.v1.threads.UpdateThreadRequest\x1a-.yandex.cloud.ai.assistants.v1.threads.Thread\"-\x82\xd3\xe4\x93\x02\'2\"/assistants/v1/threads/{thread_id}:\x01*\x12\xad\x01\n\x06\x44\x65lete\x12:.yandex.cloud.ai.assistants.v1.threads.DeleteThreadRequest\x1a;.yandex.cloud.ai.assistants.v1.threads.DeleteThreadResponse\"*\x82\xd3\xe4\x93\x02$*\"/assistants/v1/threads/{thread_id}\x12\x9d\x01\n\x04List\x12\x39.yandex.cloud.ai.assistants.v1.threads.ListThreadsRequest\x1a:.yandex.cloud.ai.assistants.v1.threads.ListThreadsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/assistants/v1/threadsB~\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threadsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.threads.thread_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.ai.assistants.v1.threadsZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/threads;threads'
  _CREATETHREADREQUEST_LABELSENTRY._options = None
  _CREATETHREADREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATETHREADREQUEST.fields_by_name['folder_id']._options = None
  _CREATETHREADREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _GETTHREADREQUEST.fields_by_name['thread_id']._options = None
  _GETTHREADREQUEST.fields_by_name['thread_id']._serialized_options = b'\350\3071\001'
  _UPDATETHREADREQUEST_LABELSENTRY._options = None
  _UPDATETHREADREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATETHREADREQUEST.fields_by_name['thread_id']._options = None
  _UPDATETHREADREQUEST.fields_by_name['thread_id']._serialized_options = b'\350\3071\001'
  _UPDATETHREADREQUEST.fields_by_name['update_mask']._options = None
  _UPDATETHREADREQUEST.fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _DELETETHREADREQUEST.fields_by_name['thread_id']._options = None
  _DELETETHREADREQUEST.fields_by_name['thread_id']._serialized_options = b'\350\3071\001'
  _LISTTHREADSREQUEST.fields_by_name['folder_id']._options = None
  _LISTTHREADSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _THREADSERVICE.methods_by_name['Create']._options = None
  _THREADSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\033\"\026/assistants/v1/threads:\001*'
  _THREADSERVICE.methods_by_name['Get']._options = None
  _THREADSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002$\022\"/assistants/v1/threads/{thread_id}'
  _THREADSERVICE.methods_by_name['Update']._options = None
  _THREADSERVICE.methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\'2\"/assistants/v1/threads/{thread_id}:\001*'
  _THREADSERVICE.methods_by_name['Delete']._options = None
  _THREADSERVICE.methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002$*\"/assistants/v1/threads/{thread_id}'
  _THREADSERVICE.methods_by_name['List']._options = None
  _THREADSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\030\022\026/assistants/v1/threads'
  _globals['_CREATETHREADREQUEST']._serialized_start=339
  _globals['_CREATETHREADREQUEST']._serialized_end=729
  _globals['_CREATETHREADREQUEST_LABELSENTRY']._serialized_start=684
  _globals['_CREATETHREADREQUEST_LABELSENTRY']._serialized_end=729
  _globals['_GETTHREADREQUEST']._serialized_start=731
  _globals['_GETTHREADREQUEST']._serialized_end=774
  _globals['_UPDATETHREADREQUEST']._serialized_start=777
  _globals['_UPDATETHREADREQUEST']._serialized_end=1117
  _globals['_UPDATETHREADREQUEST_LABELSENTRY']._serialized_start=684
  _globals['_UPDATETHREADREQUEST_LABELSENTRY']._serialized_end=729
  _globals['_DELETETHREADREQUEST']._serialized_start=1119
  _globals['_DELETETHREADREQUEST']._serialized_end=1165
  _globals['_DELETETHREADRESPONSE']._serialized_start=1167
  _globals['_DELETETHREADRESPONSE']._serialized_end=1189
  _globals['_LISTTHREADSREQUEST']._serialized_start=1191
  _globals['_LISTTHREADSREQUEST']._serialized_end=1275
  _globals['_LISTTHREADSRESPONSE']._serialized_start=1277
  _globals['_LISTTHREADSRESPONSE']._serialized_end=1387
  _globals['_THREADSERVICE']._serialized_start=1390
  _globals['_THREADSERVICE']._serialized_end=2215
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DescriptiveStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    MEAN_FIELD_NUMBER: builtins.int
    STD_FIELD_NUMBER: builtins.int
    QUANTILES_FIELD_NUMBER: builtins.int
    min: builtins.float
    """Minimum observed value"""
    max: builtins.float
    """Maximum observed value"""
    mean: builtins.float
    """Estimated mean of distribution"""
    std: builtins.float
    """Estimated standard deviation of distribution"""
    @property
    def quantiles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Quantile]:
        """List of evaluated quantiles"""

    def __init__(
        self,
        *,
        min: builtins.float = ...,
        max: builtins.float = ...,
        mean: builtins.float = ...,
        std: builtins.float = ...,
        quantiles: collections.abc.Iterable[global___Quantile] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["max", b"max", "mean", b"mean", "min", b"min", "quantiles", b"quantiles", "std", b"std"]) -> None: ...

global___DescriptiveStatistics = DescriptiveStatistics

@typing.final
class Quantile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEVEL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    level: builtins.float
    """Quantile level in range (0, 1)"""
    value: builtins.float
    """Quantile value"""
    def __init__(
        self,
        *,
        level: builtins.float = ...,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["level", b"level", "value", b"value"]) -> None: ...

global___Quantile = Quantile

@typing.final
class AudioSegmentBoundaries(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_MS_FIELD_NUMBER: builtins.int
    END_TIME_MS_FIELD_NUMBER: builtins.int
    DURATION_SECONDS_FIELD_NUMBER: builtins.int
    start_time_ms: builtins.int
    """Audio segment start time"""
    end_time_ms: builtins.int
    """Audio segment end time"""
    duration_seconds: builtins.int
    """Duration in seconds"""
    def __init__(
        self,
        *,
        start_time_ms: builtins.int = ...,
        end_time_ms: builtins.int = ...,
        duration_seconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["duration_seconds", b"duration_seconds", "end_time_ms", b"end_time_ms", "start_time_ms", b"start_time_ms"]) -> None: ...

global___AudioSegmentBoundaries = AudioSegmentBoundaries



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CertificateType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CertificateTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CertificateType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CERTIFICATE_TYPE_UNSPECIFIED: _CertificateType.ValueType  # 0
    IMPORTED: _CertificateType.ValueType  # 1
    """The certificate is imported by user."""
    MANAGED: _CertificateType.ValueType  # 2
    """The certificate is created by service."""

class CertificateType(_CertificateType, metaclass=_CertificateTypeEnumTypeWrapper):
    """Supported certificate types."""

CERTIFICATE_TYPE_UNSPECIFIED: CertificateType.ValueType  # 0
IMPORTED: CertificateType.ValueType  # 1
"""The certificate is imported by user."""
MANAGED: CertificateType.ValueType  # 2
"""The certificate is created by service."""
global___CertificateType = CertificateType

class _ChallengeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChallengeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChallengeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHALLENGE_TYPE_UNSPECIFIED: _ChallengeType.ValueType  # 0
    DNS: _ChallengeType.ValueType  # 1
    """Domain validation type that using DNS-records."""
    HTTP: _ChallengeType.ValueType  # 2
    """Domain validation type that using HTTP-files."""

class ChallengeType(_ChallengeType, metaclass=_ChallengeTypeEnumTypeWrapper):
    """Supported domain validation types."""

CHALLENGE_TYPE_UNSPECIFIED: ChallengeType.ValueType  # 0
DNS: ChallengeType.ValueType  # 1
"""Domain validation type that using DNS-records."""
HTTP: ChallengeType.ValueType  # 2
"""Domain validation type that using HTTP-files."""
global___ChallengeType = ChallengeType

@typing.final
class Certificate(google.protobuf.message.Message):
    """A certificate. For details about the concept, see [documentation](/docs/certificate-manager/concepts/)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Certificate._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Certificate._Status.ValueType  # 0
        VALIDATING: Certificate._Status.ValueType  # 1
        """The certificate domains validation are required. Used only for managed certificates."""
        INVALID: Certificate._Status.ValueType  # 2
        """The certificate issuance is failed. Used only for managed certificates."""
        ISSUED: Certificate._Status.ValueType  # 3
        """The certificate is issued."""
        REVOKED: Certificate._Status.ValueType  # 4
        """The certificate is revoked."""
        RENEWING: Certificate._Status.ValueType  # 5
        """The certificate renewal is started. Used only for managed certificates."""
        RENEWAL_FAILED: Certificate._Status.ValueType  # 6
        """The certificate renewal is failed. Used only for managed certificates."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Certificate.Status.ValueType  # 0
    VALIDATING: Certificate.Status.ValueType  # 1
    """The certificate domains validation are required. Used only for managed certificates."""
    INVALID: Certificate.Status.ValueType  # 2
    """The certificate issuance is failed. Used only for managed certificates."""
    ISSUED: Certificate.Status.ValueType  # 3
    """The certificate is issued."""
    REVOKED: Certificate.Status.ValueType  # 4
    """The certificate is revoked."""
    RENEWING: Certificate.Status.ValueType  # 5
    """The certificate renewal is started. Used only for managed certificates."""
    RENEWAL_FAILED: Certificate.Status.ValueType  # 6
    """The certificate renewal is failed. Used only for managed certificates."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DOMAINS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ISSUER_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    SERIAL_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    ISSUED_AT_FIELD_NUMBER: builtins.int
    NOT_AFTER_FIELD_NUMBER: builtins.int
    NOT_BEFORE_FIELD_NUMBER: builtins.int
    CHALLENGES_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    INCOMPLETE_CHAIN_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the certificate. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the certificate belongs to."""
    name: builtins.str
    """Name of the certificate.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the certificate."""
    type: global___CertificateType.ValueType
    """Type of the certificate."""
    status: global___Certificate.Status.ValueType
    """Status of the certificate."""
    issuer: builtins.str
    """[Distinguished Name](https://tools.ietf.org/html/rfc1779) of the certificate authority that issued the certificate."""
    subject: builtins.str
    """[Distinguished Name](https://tools.ietf.org/html/rfc1779) of the entity that is associated with the public key contained in the certificate."""
    serial: builtins.str
    """Serial number of the certificate."""
    deletion_protection: builtins.bool
    """Flag that protects deletion of the certificate"""
    incomplete_chain: builtins.bool
    """Mark imported certificates without uploaded chain or with chain which not lead to root certificate"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Certificate labels as `key:value` pairs."""

    @property
    def domains(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Fully qualified domain names of the certificate."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the certificate is updated."""

    @property
    def issued_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the certificate is issued."""

    @property
    def not_after(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time after which the certificate is not valid."""

    @property
    def not_before(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time before which the certificate is not valid."""

    @property
    def challenges(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Challenge]:
        """Domains validation challenges of the certificate. Used only for managed certificates."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        type: global___CertificateType.ValueType = ...,
        domains: collections.abc.Iterable[builtins.str] | None = ...,
        status: global___Certificate.Status.ValueType = ...,
        issuer: builtins.str = ...,
        subject: builtins.str = ...,
        serial: builtins.str = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        issued_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        not_after: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        not_before: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        challenges: collections.abc.Iterable[global___Challenge] | None = ...,
        deletion_protection: builtins.bool = ...,
        incomplete_chain: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "issued_at", b"issued_at", "not_after", b"not_after", "not_before", b"not_before", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["challenges", b"challenges", "created_at", b"created_at", "deletion_protection", b"deletion_protection", "description", b"description", "domains", b"domains", "folder_id", b"folder_id", "id", b"id", "incomplete_chain", b"incomplete_chain", "issued_at", b"issued_at", "issuer", b"issuer", "labels", b"labels", "name", b"name", "not_after", b"not_after", "not_before", b"not_before", "serial", b"serial", "status", b"status", "subject", b"subject", "type", b"type", "updated_at", b"updated_at"]) -> None: ...

global___Certificate = Certificate

@typing.final
class Challenge(google.protobuf.message.Message):
    """Domain validation challenge."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Challenge._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Challenge._Status.ValueType  # 0
        PENDING: Challenge._Status.ValueType  # 1
        """The challenge is waiting to be completed."""
        PROCESSING: Challenge._Status.ValueType  # 2
        """The challenge is awaiting approval from Let's Encrypt."""
        VALID: Challenge._Status.ValueType  # 3
        """The challenge is complete."""
        INVALID: Challenge._Status.ValueType  # 4
        """The rights check for a specific domain failed or the one-week period allocated for the check expired."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Challenge.Status.ValueType  # 0
    PENDING: Challenge.Status.ValueType  # 1
    """The challenge is waiting to be completed."""
    PROCESSING: Challenge.Status.ValueType  # 2
    """The challenge is awaiting approval from Let's Encrypt."""
    VALID: Challenge.Status.ValueType  # 3
    """The challenge is complete."""
    INVALID: Challenge.Status.ValueType  # 4
    """The rights check for a specific domain failed or the one-week period allocated for the check expired."""

    @typing.final
    class DnsRecord(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Name of the DNS record."""
        type: builtins.str
        """Type of the DNS-record."""
        value: builtins.str
        """Value of the DNS-record."""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            type: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["name", b"name", "type", b"type", "value", b"value"]) -> None: ...

    @typing.final
    class HttpFile(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        URL_FIELD_NUMBER: builtins.int
        CONTENT_FIELD_NUMBER: builtins.int
        url: builtins.str
        """Location of the HTTP file."""
        content: builtins.str
        """Content of the HTTP file."""
        def __init__(
            self,
            *,
            url: builtins.str = ...,
            content: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["content", b"content", "url", b"url"]) -> None: ...

    DOMAIN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    DNS_CHALLENGE_FIELD_NUMBER: builtins.int
    HTTP_CHALLENGE_FIELD_NUMBER: builtins.int
    domain: builtins.str
    """Domain of the challenge."""
    type: global___ChallengeType.ValueType
    """Type of the challenge."""
    status: global___Challenge.Status.ValueType
    """Status of the challenge."""
    message: builtins.str
    """Description of the challenge."""
    error: builtins.str
    """Error of the challenge."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the challenge is created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the challenge is updated."""

    @property
    def dns_challenge(self) -> global___Challenge.DnsRecord:
        """DNS-record."""

    @property
    def http_challenge(self) -> global___Challenge.HttpFile:
        """HTTP-file."""

    def __init__(
        self,
        *,
        domain: builtins.str = ...,
        type: global___ChallengeType.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: global___Challenge.Status.ValueType = ...,
        message: builtins.str = ...,
        error: builtins.str = ...,
        dns_challenge: global___Challenge.DnsRecord | None = ...,
        http_challenge: global___Challenge.HttpFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["challenge", b"challenge", "created_at", b"created_at", "dns_challenge", b"dns_challenge", "http_challenge", b"http_challenge", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["challenge", b"challenge", "created_at", b"created_at", "dns_challenge", b"dns_challenge", "domain", b"domain", "error", b"error", "http_challenge", b"http_challenge", "message", b"message", "status", b"status", "type", b"type", "updated_at", b"updated_at"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["challenge", b"challenge"]) -> typing.Literal["dns_challenge", "http_challenge"] | None: ...

global___Challenge = Challenge

@typing.final
class Version(google.protobuf.message.Message):
    """A certificate version"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the version."""
    certificate_id: builtins.str
    """ID of the certificate that the version belongs to."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the version was created."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        certificate_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["certificate_id", b"certificate_id", "created_at", b"created_at", "id", b"id"]) -> None: ...

global___Version = Version



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/storage/v1/s3api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/storage/v1/s3api.proto\x12\x17yandex.cloud.storage.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcd\x05\n\x16S3APIGetObjectResponse\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x15\n\raccept_ranges\x18\x03 \x01(\t\x12\x15\n\rcache_control\x18\x04 \x01(\t\x12\x1b\n\x13\x63ontent_disposition\x18\x05 \x01(\t\x12\x18\n\x10\x63ontent_encoding\x18\x06 \x01(\t\x12\x18\n\x10\x63ontent_language\x18\x07 \x01(\t\x12\x16\n\x0e\x63ontent_length\x18\x08 \x01(\x03\x12\x15\n\rcontent_range\x18\t \x01(\t\x12\x14\n\x0c\x63ontent_type\x18\n \x01(\t\x12\x12\n\nversion_id\x18\x0b \x01(\t\x12.\n\nexpires_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_modified_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12O\n\x08metadata\x18\x0e \x03(\x0b\x32=.yandex.cloud.storage.v1.S3APIGetObjectResponse.MetadataEntry\x12\x15\n\rstorage_class\x18\x0f \x01(\t\x12\x1e\n\x16server_side_encryption\x18\x10 \x01(\t\x12\x16\n\x0esse_kms_key_id\x18\x11 \x01(\t\x12\x18\n\x10object_lock_mode\x18\x12 \x01(\t\x12\x41\n\x1dobject_lock_retain_until_date\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12%\n\x1dobject_lock_legal_hold_status\x18\x14 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"N\n\x16S3APIPutObjectResponse\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x12\n\nversion_id\x18\x03 \x01(\t\"C\n\x19S3APIDeleteObjectResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"V\n\x10\x43opyObjectResult\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\x34\n\x10last_modified_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa8\x01\n\x17S3APICopyObjectResponse\x12\x45\n\x12\x63opy_object_result\x18\x01 \x01(\x0b\x32).yandex.cloud.storage.v1.CopyObjectResult\x12\x12\n\nrequest_id\x18\x02 \x01(\t\x12\x1e\n\x16\x63opy_source_version_id\x18\x03 \x01(\t\x12\x12\n\nversion_id\x18\x04 \x01(\t\"u\n\x19SuccessfullyDeletedObject\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x15\n\rdelete_marker\x18\x03 \x01(\x08\x12 \n\x18\x64\x65lete_marker_version_id\x18\x04 \x01(\t\"O\n\x11\x44\x65leteObjectError\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0b\n\x03msg\x18\x04 \x01(\t\"\xb1\x01\n\x1aS3APIDeleteObjectsResponse\x12\x43\n\x07\x64\x65leted\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.storage.v1.SuccessfullyDeletedObject\x12:\n\x06\x65rrors\x18\x02 \x03(\x0b\x32*.yandex.cloud.storage.v1.DeleteObjectError\x12\x12\n\nrequest_id\x18\x03 \x01(\t\"5\n\x1fS3APIPutObjectRetentionResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"Z\n\x13ObjectLockRetention\x12\x0c\n\x04mode\x18\x01 \x01(\t\x12\x35\n\x11retain_until_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"v\n\x1fS3APIGetObjectRetentionResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12?\n\tretention\x18\x02 \x01(\x0b\x32,.yandex.cloud.storage.v1.ObjectLockRetention\"5\n\x1fS3APIPutObjectLegalHoldResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\"%\n\x13ObjectLockLegalHold\x12\x0e\n\x06status\x18\x01 \x01(\t\"w\n\x1fS3APIGetObjectLegalHoldResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12@\n\nlegal_hold\x18\x02 \x01(\x0b\x32,.yandex.cloud.storage.v1.ObjectLockLegalHold\"G\n\x1dS3APIPutObjectTaggingResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"\'\n\tObjectTag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"|\n\x1dS3APIGetObjectTaggingResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x33\n\x07tag_set\x18\x03 \x03(\x0b\x32\".yandex.cloud.storage.v1.ObjectTag\"J\n S3APIDeleteObjectTaggingResponse\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\tBb\n\x1byandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.storage.v1.s3api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storage'
  _S3APIGETOBJECTRESPONSE_METADATAENTRY._options = None
  _S3APIGETOBJECTRESPONSE_METADATAENTRY._serialized_options = b'8\001'
  _globals['_S3APIGETOBJECTRESPONSE']._serialized_start=98
  _globals['_S3APIGETOBJECTRESPONSE']._serialized_end=815
  _globals['_S3APIGETOBJECTRESPONSE_METADATAENTRY']._serialized_start=768
  _globals['_S3APIGETOBJECTRESPONSE_METADATAENTRY']._serialized_end=815
  _globals['_S3APIPUTOBJECTRESPONSE']._serialized_start=817
  _globals['_S3APIPUTOBJECTRESPONSE']._serialized_end=895
  _globals['_S3APIDELETEOBJECTRESPONSE']._serialized_start=897
  _globals['_S3APIDELETEOBJECTRESPONSE']._serialized_end=964
  _globals['_COPYOBJECTRESULT']._serialized_start=966
  _globals['_COPYOBJECTRESULT']._serialized_end=1052
  _globals['_S3APICOPYOBJECTRESPONSE']._serialized_start=1055
  _globals['_S3APICOPYOBJECTRESPONSE']._serialized_end=1223
  _globals['_SUCCESSFULLYDELETEDOBJECT']._serialized_start=1225
  _globals['_SUCCESSFULLYDELETEDOBJECT']._serialized_end=1342
  _globals['_DELETEOBJECTERROR']._serialized_start=1344
  _globals['_DELETEOBJECTERROR']._serialized_end=1423
  _globals['_S3APIDELETEOBJECTSRESPONSE']._serialized_start=1426
  _globals['_S3APIDELETEOBJECTSRESPONSE']._serialized_end=1603
  _globals['_S3APIPUTOBJECTRETENTIONRESPONSE']._serialized_start=1605
  _globals['_S3APIPUTOBJECTRETENTIONRESPONSE']._serialized_end=1658
  _globals['_OBJECTLOCKRETENTION']._serialized_start=1660
  _globals['_OBJECTLOCKRETENTION']._serialized_end=1750
  _globals['_S3APIGETOBJECTRETENTIONRESPONSE']._serialized_start=1752
  _globals['_S3APIGETOBJECTRETENTIONRESPONSE']._serialized_end=1870
  _globals['_S3APIPUTOBJECTLEGALHOLDRESPONSE']._serialized_start=1872
  _globals['_S3APIPUTOBJECTLEGALHOLDRESPONSE']._serialized_end=1925
  _globals['_OBJECTLOCKLEGALHOLD']._serialized_start=1927
  _globals['_OBJECTLOCKLEGALHOLD']._serialized_end=1964
  _globals['_S3APIGETOBJECTLEGALHOLDRESPONSE']._serialized_start=1966
  _globals['_S3APIGETOBJECTLEGALHOLDRESPONSE']._serialized_end=2085
  _globals['_S3APIPUTOBJECTTAGGINGRESPONSE']._serialized_start=2087
  _globals['_S3APIPUTOBJECTTAGGINGRESPONSE']._serialized_end=2158
  _globals['_OBJECTTAG']._serialized_start=2160
  _globals['_OBJECTTAG']._serialized_end=2199
  _globals['_S3APIGETOBJECTTAGGINGRESPONSE']._serialized_start=2201
  _globals['_S3APIGETOBJECTTAGGINGRESPONSE']._serialized_end=2325
  _globals['_S3APIDELETEOBJECTTAGGINGRESPONSE']._serialized_start=2327
  _globals['_S3APIDELETEOBJECTTAGGINGRESPONSE']._serialized_end=2401
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mysql/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.mysql.v1.config import mysql5_7_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_config_dot_mysql5__7__pb2
from yandex.cloud.mdb.mysql.v1.config import mysql8_0_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_config_dot_mysql8__0__pb2
from yandex.cloud.mdb.mysql.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_mysql_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/mdb/mysql/v1/cluster.proto\x12\x19yandex.cloud.mdb.mysql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x1dyandex/cloud/validation.proto\x1a/yandex/cloud/mdb/mysql/v1/config/mysql5_7.proto\x1a/yandex/cloud/mdb/mysql/v1/config/mysql8_0.proto\x1a+yandex/cloud/mdb/mysql/v1/maintenance.proto\"\x9c\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12>\n\x06labels\x18\x06 \x03(\x0b\x32..yandex.cloud.mdb.mysql.v1.Cluster.LabelsEntry\x12\x43\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32..yandex.cloud.mdb.mysql.v1.Cluster.Environment\x12\x39\n\nmonitoring\x18\x08 \x03(\x0b\x32%.yandex.cloud.mdb.mysql.v1.Monitoring\x12\x38\n\x06\x63onfig\x18\t \x01(\x0b\x32(.yandex.cloud.mdb.mysql.v1.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12\x39\n\x06health\x18\x0b \x01(\x0e\x32).yandex.cloud.mdb.mysql.v1.Cluster.Health\x12\x39\n\x06status\x18\x0c \x01(\x0e\x32).yandex.cloud.mdb.mysql.v1.Cluster.Status\x12H\n\x12maintenance_window\x18\r \x01(\x0b\x32,.yandex.cloud.mdb.mysql.v1.MaintenanceWindow\x12J\n\x11planned_operation\x18\x0e \x01(\x0b\x32/.yandex.cloud.mdb.mysql.v1.MaintenanceOperation\x12\x1a\n\x12security_group_ids\x18\x0f \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x10 \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\x11 \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xb3\x04\n\rClusterConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12`\n\x10mysql_config_5_7\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.mdb.mysql.v1.config.MysqlConfigSet5_7H\x00R\x0fmysqlConfig_5_7\x12`\n\x10mysql_config_8_0\x18\x06 \x01(\x0b\x32\x33.yandex.cloud.mdb.mysql.v1.config.MysqlConfigSet8_0H\x00R\x0fmysqlConfig_8_0\x12\x37\n\tresources\x18\x03 \x01(\x0b\x32$.yandex.cloud.mdb.mysql.v1.Resources\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12\x31\n\x06\x61\x63\x63\x65ss\x18\x05 \x01(\x0b\x32!.yandex.cloud.mdb.mysql.v1.Access\x12R\n\x17performance_diagnostics\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.mdb.mysql.v1.PerformanceDiagnostics\x12H\n\x19\x62\x61\x63kup_retain_period_days\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x37-60B\x0e\n\x0cmysql_config\"\xa0\x04\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x37\n\tresources\x18\x04 \x01(\x0b\x32$.yandex.cloud.mdb.mysql.v1.Resources\x12\x32\n\x04role\x18\x05 \x01(\x0e\x32$.yandex.cloud.mdb.mysql.v1.Host.Role\x12\x36\n\x06health\x18\x06 \x01(\x0e\x32&.yandex.cloud.mdb.mysql.v1.Host.Health\x12\x34\n\x08services\x18\x07 \x03(\x0b\x32\".yandex.cloud.mdb.mysql.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\x12\x1a\n\x12replication_source\x18\n \x01(\t\x12\"\n\x0f\x62\x61\x63kup_priority\x18\x0b \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x1b\n\x08priority\x18\x0c \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\"1\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"M\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0c\n\x08READONLY\x10\x04\"\xe5\x01\n\x07Service\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.yandex.cloud.mdb.mysql.v1.Service.Type\x12\x39\n\x06health\x18\x02 \x01(\x0e\x32).yandex.cloud.mdb.mysql.v1.Service.Health\"\'\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05MYSQL\x10\x01\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08READONLY\x10\x03\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"C\n\x06\x41\x63\x63\x65ss\x12\x11\n\tdata_lens\x18\x01 \x01(\x08\x12\x0f\n\x07web_sql\x18\x02 \x01(\x08\x12\x15\n\rdata_transfer\x18\x03 \x01(\x08\"\x8d\x01\n\x16PerformanceDiagnostics\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12/\n\x1asessions_sampling_interval\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-86400\x12\x31\n\x1cstatements_sampling_interval\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-86400Bd\n\x1dyandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysql'
  _CLUSTER_LABELSENTRY._options = None
  _CLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _CLUSTERCONFIG.fields_by_name['backup_retain_period_days']._options = None
  _CLUSTERCONFIG.fields_by_name['backup_retain_period_days']._serialized_options = b'\372\3071\0047-60'
  _HOST.fields_by_name['backup_priority']._options = None
  _HOST.fields_by_name['backup_priority']._serialized_options = b'\372\3071\0050-100'
  _HOST.fields_by_name['priority']._options = None
  _HOST.fields_by_name['priority']._serialized_options = b'\372\3071\0050-100'
  _PERFORMANCEDIAGNOSTICS.fields_by_name['sessions_sampling_interval']._options = None
  _PERFORMANCEDIAGNOSTICS.fields_by_name['sessions_sampling_interval']._serialized_options = b'\372\3071\0071-86400'
  _PERFORMANCEDIAGNOSTICS.fields_by_name['statements_sampling_interval']._options = None
  _PERFORMANCEDIAGNOSTICS.fields_by_name['statements_sampling_interval']._serialized_options = b'\372\3071\0071-86400'
  _globals['_CLUSTER']._serialized_start=339
  _globals['_CLUSTER']._serialized_end=1391
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=1083
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1128
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1130
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1203
  _globals['_CLUSTER_HEALTH']._serialized_start=1205
  _globals['_CLUSTER_HEALTH']._serialized_end=1268
  _globals['_CLUSTER_STATUS']._serialized_start=1270
  _globals['_CLUSTER_STATUS']._serialized_end=1391
  _globals['_MONITORING']._serialized_start=1393
  _globals['_MONITORING']._serialized_end=1454
  _globals['_CLUSTERCONFIG']._serialized_start=1457
  _globals['_CLUSTERCONFIG']._serialized_end=2020
  _globals['_HOST']._serialized_start=2023
  _globals['_HOST']._serialized_end=2567
  _globals['_HOST_ROLE']._serialized_start=2439
  _globals['_HOST_ROLE']._serialized_end=2488
  _globals['_HOST_HEALTH']._serialized_start=2490
  _globals['_HOST_HEALTH']._serialized_end=2567
  _globals['_SERVICE']._serialized_start=2570
  _globals['_SERVICE']._serialized_end=2799
  _globals['_SERVICE_TYPE']._serialized_start=2695
  _globals['_SERVICE_TYPE']._serialized_end=2734
  _globals['_SERVICE_HEALTH']._serialized_start=2736
  _globals['_SERVICE_HEALTH']._serialized_end=2799
  _globals['_RESOURCES']._serialized_start=2801
  _globals['_RESOURCES']._serialized_end=2881
  _globals['_ACCESS']._serialized_start=2883
  _globals['_ACCESS']._serialized_end=2950
  _globals['_PERFORMANCEDIAGNOSTICS']._serialized_start=2953
  _globals['_PERFORMANCEDIAGNOSTICS']._serialized_end=3094
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BillingAccount(google.protobuf.message.Message):
    """A BillingAccount resource. For more information, see [BillingAccount](/docs/billing/concepts/billing-account)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    CURRENCY_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    BALANCE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the billing account."""
    name: builtins.str
    """Name of the billing account."""
    country_code: builtins.str
    """ISO 3166-1 alpha-2 country code of the billing account."""
    currency: builtins.str
    """Currency of the billing account.
    Can be one of the following:
    * `RUB`
    * `USD`
    * `KZT`
    """
    active: builtins.bool
    """Represents whether corresponding billable objects can be used or not."""
    balance: builtins.str
    """Current balance of the billing account."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        country_code: builtins.str = ...,
        currency: builtins.str = ...,
        active: builtins.bool = ...,
        balance: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["active", b"active", "balance", b"balance", "country_code", b"country_code", "created_at", b"created_at", "currency", b"currency", "id", b"id", "name", b"name"]) -> None: ...

global___BillingAccount = BillingAccount



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Health:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HealthEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Health.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HEALTH_UNKNOWN: _Health.ValueType  # 0
    """Object is in unknown state (we have no data)."""
    ALIVE: _Health.ValueType  # 1
    """Object is alive and well (for example, all hosts of the cluster are alive)."""
    DEAD: _Health.ValueType  # 2
    """Object is inoperable (it cannot perform any of its essential functions)."""
    DEGRADED: _Health.ValueType  # 3
    """Object is partially alive (it can perform some of its essential functions)."""

class Health(_Health, metaclass=_HealthEnumTypeWrapper): ...

HEALTH_UNKNOWN: Health.ValueType  # 0
"""Object is in unknown state (we have no data)."""
ALIVE: Health.ValueType  # 1
"""Object is alive and well (for example, all hosts of the cluster are alive)."""
DEAD: Health.ValueType  # 2
"""Object is inoperable (it cannot perform any of its essential functions)."""
DEGRADED: Health.ValueType  # 3
"""Object is partially alive (it can perform some of its essential functions)."""
global___Health = Health

@typing.final
class Resources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the resource preset for computational resources available to a host (CPU, memory etc.).
    All available presets are listed in the [documentation](/docs/data-proc/concepts/instance-types).
    """
    disk_type_id: builtins.str
    """Type of the storage environment for the host.
    Possible values:
    * network-hdd - network HDD drive,
    * network-ssd - network SSD drive.
    """
    disk_size: builtins.int
    """Volume of the storage available to a host, in bytes."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_type_id: builtins.str = ...,
        disk_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources
